m4_define(PROGRAM, para_mixer)
m4_define(DEFAULT_CONFIG_FILE, ~/.paraslash/mixer.conf)
[suite mixer]
version-string = GIT_VERSION()
caption = List of subcommands
[supercommand para_mixer]
	purpose = alarm clock and volume-fader for OSS and ALSA
	synopsis = [<options>] -- [<subcommand>] [<subcommand_options>]
	[description]
		para_mixer adjusts the settings of an audio mixing device. It can
		set the level of a mixer channel, or fade the level from one value
		to another in a given time period. The sleep and snooze subcommands
		contact para_server to start or stop streaming.
	[/description]
	m4_include(common-option-section.m4)
	m4_include(help.m4)
	m4_include(detailed-help.m4)
	m4_include(version.m4)
	m4_include(config-file.m4)
	m4_include(loglevel.m4)
	m4_include(per-command-options-section.m4)
	[help]
		These options apply to several subcommands.
	[/help]
	[option mixer-api]
		short_opt = a
		summary = select alternative mixer API
		arg_info = required_arg
		arg_type = string
		typestr = api
		[help]
			ALSA is preferred over OSS if both APIs are supported and this option
			is not given. To see the supported mixer APIs, use this option with
			an invalid string as the mixer API, e.g. --mixer-api help.
		[/help]
	[option mixer-device]
		short_opt = m
		summary = set mixer device
		arg_info = required_arg
		arg_type = string
		typestr = device
		[help]
			The default device (used if this option is not given) depends
			on the selected mixer API. For ALSA, the default is 'hw:0' which
			corresponds to the first sound device. For OSS, '/dev/mixer' is used
			as the default.
		[/help]
	[option mixer-channel]
		short_opt = C
		summary = select a mixer channel
		arg_info = required_arg
		arg_type = string
		typestr = channel
		[help]
			For the ALSA mixer API, the possible values are determined at runtime
			depending on the hardware and can be printed by specifying an invalid
			mixer channel, for example --mixer-channel help. The default channel is
			'Master'.

			For OSS the possible values are invariably 'volume', 'bass', 'treble',
			'synth', 'pcm', 'speaker', 'line', 'mic', 'cd', 'imix', 'altpcm',
			'reclev', 'igain', 'ogain'. However, not all listed channels might be
			supported on any particular hardware. The default channel is 'volume'.
		[/help]
	[option fade-exponent]
		summary = set non-linear time scale for fading
		arg_info = required_arg
		arg_type = uint32
		typestr = value
		default_val = 0
		[help]
			This option affects the fade, snooze and sleep subcommands. It is
			ignored in set mode.

			The argument must be a number between 0 and 100. The default value
			0 corresponds to linear scaling. That is, the value of the mixer
			channel is increased or decreased in fixed time intervals until the
			destination value is reached. Exponents between 1 and 99 cause low
			channel values to be increased more quickly than high channel values.
			Large exponents cause greater differences. The special value 100 sets
			the destination value immediately. The command then sleeps for the
			configured fade time.
		[/help]
[subcommand help]
	purpose = print subcommand help
	non-opts-name = [<subcommand>]
	[option long]
		summary = print the long help text
		short_opt = l

[subcommand set]
	purpose = set a channel to the given value and exit
	[option val]
		summary = mixer channel value to set
		arg_info = required_arg
		arg_type = uint32
		typestr = value
		default_val = 10
[subcommand fade]
	purpose = fade a channel to the given value in the given time
	[option fade-vol]
		short_opt = f
		summary = destination volume for fading
		arg_info = required_arg
		arg_type = uint32
		typestr = volume
		default_val = 50
	[option fade-time]
		short_opt = t
		summary = duration of fade period
		arg_info = required_arg
		arg_type = uint32
		typestr = seconds
		default_val = 5
[subcommand snooze]
	purpose = fade out, pause, sleep, play, fade in
	[option so-time]
		summary = duration of fade-out period
		arg_info = required_arg
		arg_type = uint32
		typestr = seconds
		default_val = 30
	[option so-vol]
		summary = destination volume for fade-out
		arg_info = required_arg
		arg_type = uint32
		typestr = volume
		default_val = 20
	[option snooze-time]
		summary = delay between end of fade-out and begin of fade-in
		arg_info = required_arg
		arg_type = uint32
		typestr = seconds
		default_val = 600
	[option si-time]
		summary = duration of fade-in period
		arg_info = required_arg
		arg_type = uint32
		typestr = seconds
		default_val = 180
	[option si-vol]
		summary = destination volume for fade-in
		arg_info = required_arg
		arg_type = uint32
		typestr = volume
		default_val = 80
[subcommand sleep]
	purpose = stream, fade out, sleep, fade in
	[description]
		Set the initial volume and mood, start playing and sleep. Then switch
		to the fade-out mood and fade to the fade-out volume. Next, switch to
		the sleep mood and wait until wake time minus fade-in time. Finally,
		switch to the wake mood and fade in to the fade-in volume.
	[/description]
	[option ivol]
		summary = set initial volume
		arg_info = required_arg
		arg_type = string
		default_val = 60
		flag multiple
		typestr = [channel:]volume
		[help]
			Used as the start volume, before fading out to the fade-out volume. The
			channel part may be omitted, in which case the default channel is
			used. This option may be given multiple times.
		[/help]
	[option initial-mood]
		summary = mood or playlist to start with
		arg_info = required_arg
		arg_type = string
		typestr = mood_spec
		[help]
			This mood or playlist is selected right after setting the initial
			volume and before fade-out starts. If unset, fade-out starts
			immediately.
		[/help]
	[option initial-delay]
		summary = time before fade-out starts.
		arg_info = required_arg
		arg_type = uint32
		typestr = seconds
		default_val = 0
		[help]
			If left at the default, no initial delay occurs even if an initial
			mood is given.
		[/help]
	[option fo-mood]
		summary = mood or playlist for fade-out
		arg_info = required_arg
		arg_type = string
		typestr = mood_spec
		[help]
			This mood (or playlist) is selected right after setting the initial
			volume.
		[/help]
	[option fo-time]
		summary = duration of fade-out period
		arg_info = required_arg
		arg_type = uint32
		typestr = seconds
		default_val = 1800
		[help]
			No fading if this is set to 0.
		[/help]
	[option fo-vol]
		summary = destination volume for fade-out
		arg_info = required_arg
		arg_type = uint32
		typestr = volume
		default_val = 20
	[option sleep-mood]
		summary = mood/playlist between fade-out and fade-in
		arg_info = required_arg
		arg_type = string
		typestr = mood_spec
		[help]
			Select the given mood or playlist after the fade-out. If unset,
			playback is stopped until fade-in starts.
		[/help]
	[option wake-time]
		short_opt = w
		summary = when to start fade in
		arg_info = required_arg
		arg_type = string
		typestr = [+][HH][:MM]
		default_val = +9:00
		[help]
			If the optional plus character is given, the wake time is computed as
			now + HH hours + MM minutes. Otherwise the HH:MM argument is considered
			an absolute time (referring to either the current or the next day).
		[/help]
	[option fi-mood]
		summary = mood or playlist for fade-in
		arg_info = required_arg
		arg_type = string
		typestr = mood_spec
		[help]
			This mood or playlist is selected right before fade-in begins.
		[/help]
	[option fi-time]
		summary = duration of fade-in period
		arg_info = required_arg
		arg_type = uint32
		typestr = seconds
		default_val = 1200
		[help]
			No fading if this is set to 0.
		[/help]
	[option fi-vol]
		summary = destination volume for fade-in
		arg_info = required_arg
		arg_type = uint32
		typestr = volume
		default_val = 80
