/* Copyright (C) 2006 Andre Noll <maan@tuebingen.mpg.de>, see file COPYING. */
/** \file net.h exported symbols from net.c */

/* Userland defines for Linux DCCP support. */

#ifndef SOL_DCCP
#define SOL_DCCP 269 /**< Linux socket level. */
#endif

/** The maximum length of the host component in an URL. */
#define MAX_HOSTLEN 256

/* Opaque, only known to net.c. */
struct flowopts;

struct flowopts *flowopt_new(void);
void flowopt_add(struct flowopts *fo, int level, int opt,
		const char *name, const void *val, int len);
void flowopt_cleanup(struct flowopts *fo);

/**
 * Functions to parse and validate (parts of) URLs.
 */
char *parse_cidr(const char *cidr,
		char *addr, ssize_t addrlen, int32_t *netmask);
char *parse_url(const char *url,
		char *host, ssize_t hostlen, int32_t *port);
__malloc char *format_url(const char *url, int default_port);
const char *stringify_port(int port, const char *transport);

int lookup_address(unsigned l4type, bool passive, const char *host,
		int port_number, struct addrinfo **result);

/**
 * Generic socket creation (passive and active sockets).
 */
int makesock(unsigned l4type, bool passive, const char *host,
		uint16_t port_number, struct flowopts *fo);

int makesock_addrinfo(unsigned l4type, bool passive, struct addrinfo *ai,
		struct flowopts *fo);

static inline int para_connect(unsigned l4type, const char *host, uint16_t port)
{
	return makesock(l4type, false, host, port, NULL);
}

void extract_v4_addr(const struct sockaddr_storage *ss, struct in_addr *ia);
bool sockaddr_equal(const struct sockaddr *sa1, const struct sockaddr *sa2);

/**
 * Functions to support listening sockets.
 */
/** How many pending connections queue of a listening server will hold. */
#define BACKLOG	10

int para_listen(unsigned l4type, const char *addr, uint16_t port);
int para_listen_simple(unsigned l4type, uint16_t port);

/** Pretty-printing of IPv4/6 socket addresses */
char *remote_name(int sockfd);

/**
 * Determining maximum payload (packet) size
 */
int generic_max_transport_msg_size(int sockfd);

int recv_bin_buffer(int fd, char *buf, size_t size);
int recv_buffer(int fd, char *buf, size_t size);

int para_accept(int fd, void *addr, socklen_t size, int *new_fd);
int create_local_socket(const char *name);
int connect_local_socket(const char *name);
int recv_cred_buffer(int, char *, size_t);
ssize_t send_cred_buffer(int, char*);

/**
 * Functions and definitions to support \p IPPROTO_DCCP
 */
/** Hardcoded maximum number of separate CCID modules compiled into a host. */
#define DCCP_MAX_HOST_CCIDS	20
int dccp_available_ccids(uint8_t **ccid_array);
